@@ -1,7 +1,7 @@
 import mcpi
 
-from .thing import Thing
 from .house import House
+from .thing import Thing
 
 
 class Building(Thing):
@@ -19,7 +19,7 @@ class Building(Thing):
         init_height = init_y
 
         for i in range(0, self.floors):
-            house = House(self.server, house_pos)
+            house = House(house_pos)
             house_pos.y = house.height * i + init_height
             house.width = self.width
             house.block = self.block
